@@ -759,6 +759,18 @@ select `first name`
           employees OFFSET 4
         "###);
 
+        assert_display_snapshot!((compile(r###"
+        from employees
+        take 5..5
+        "###)?), @r###"
+        SELECT
+          employees.*
+        FROM
+          employees
+        LIMIT
+          1 OFFSET 4
+        "###);
+
         // should be one SELECT
         assert_display_snapshot!((compile(r###"
         from employees
@@ -940,7 +952,7 @@ select `first name`
         assert_snapshot!((compile(r###"
         from x
         join y [x.id]
-        "###).unwrap_err().to_string()), @r###"Error { span: None, reason: Expected { who: Some("join"), expected: "An identifer with only one part; no `.`", found: "A multipart identifer" }, help: None }"###);
+        "###).unwrap_err().to_string()), @r###"Error { span: None, reason: Expected { who: Some("join"), expected: "An identifier with only one part; no `.`", found: "A multipart identifier" }, help: None }"###);
 
         Ok(())
     }
