@@ -7,7 +7,7 @@ mod reporting;
 mod scope;
 mod transforms;
 
-use crate::ast::Node;
+use crate::ast::{Node, Query};
 
 pub use self::context::Context;
 pub use self::declarations::{Declaration, Declarations};
@@ -18,10 +18,10 @@ pub use reporting::{collect_frames, label_references};
 /// Runs semantic analysis on the query, using current state.
 ///
 /// Note that this removes function declarations from AST and saves them as current context.
-pub fn resolve(nodes: Vec<Node>, context: Option<Context>) -> anyhow::Result<(Vec<Node>, Context)> {
+pub fn resolve(query: Query, context: Option<Context>) -> anyhow::Result<(Vec<Node>, Context)> {
     let context = context.unwrap_or_else(load_std_lib);
 
-    let (nodes, context) = name_resolver::resolve_names(nodes, context)?;
+    let (nodes, context) = name_resolver::resolve_names(query, context)?;
     Ok((nodes, context))
 }
 
@@ -30,6 +30,6 @@ pub fn load_std_lib() -> Context {
     let std_lib = include_str!("./stdlib.prql");
     let nodes = parse(std_lib).unwrap().nodes;
 
-    let (_, context) = name_resolver::resolve_names(nodes, Context::default()).unwrap();
+    let (_, context) = name_resolver::resolve_nodes(nodes, Context::default()).unwrap();
     context
 }
