@@ -406,7 +406,7 @@ fn range_of_ranges(ranges: Vec<Range>) -> Result<Range<i64>> {
     if current
         .start
         .zip(current.end)
-        .map(|(s, e)| e <= s)
+        .map(|(s, e)| e < s)
         .unwrap_or(false)
     {
         bail!("Range end is before its start.");
@@ -572,6 +572,7 @@ fn translate_item(item: Item, dialect: &dyn DialectHandler) -> Result<Expr> {
                 args,
                 distinct: false,
                 over: None,
+                special: false,
             })
         }
         Item::Interval(interval) => {
@@ -712,6 +713,7 @@ fn translate_func_call(func_call: FuncCall, dialect: &dyn DialectHandler) -> Res
             .collect::<Result<Vec<_>>>()?,
         over: None,
         distinct: false,
+        special: false,
     })
 }
 fn translate_column_sort(sort: ColumnSort, dialect: &dyn DialectHandler) -> Result<OrderByExpr> {
@@ -742,10 +744,10 @@ fn translate_join(t: &Transform, dialect: &dyn DialectHandler) -> Result<Join> {
                         .map_err(|_| {
                             Error::new(Reason::Expected {
                                 who: Some("join".to_string()),
-                                expected: "An identifer with only one part; no `.`".to_string(),
+                                expected: "An identifier with only one part; no `.`".to_string(),
                                 // TODO: Add in the actual item (but I couldn't
                                 // get the error types to agree)
-                                found: "A multipart identifer".to_string(),
+                                found: "A multipart identifier".to_string(),
                             })
                         })?,
                 ),
@@ -803,9 +805,9 @@ fn translate_ident(ident: String, dialect: &dyn DialectHandler) -> Vec<sql_ast::
         // project, which may be a cause). I'm not 100% it's watertight, but we'll see.
         Dialect::BigQuery => {
             if ident.split('.').count() > 2 {
-                return vec![sql_ast::Ident::with_quote(dialect.ident_quote(), ident)];
+                vec![sql_ast::Ident::with_quote(dialect.ident_quote(), ident)]
             } else {
-                return vec![sql_ast::Ident::new(ident)];
+                vec![sql_ast::Ident::new(ident)]
             }
         }
         _ => ident
@@ -867,6 +869,8 @@ impl SQLExpression for Expr {
 
             Expr::UnaryOp { op, .. } => op.binding_strength(),
 
+            Expr::Like { .. } | Expr::ILike { .. } => 7,
+
             Expr::IsNull(_) | Expr::IsNotNull(_) => 5,
 
             // all other items types bind stronger (function calls, literals, ...)
@@ -881,7 +885,6 @@ impl SQLExpression for BinaryOperator {
             Modulo | Multiply | Divide => 11,
             Minus | Plus => 10,
 
-            ILike | NotILike | Like | NotLike => 7,
             Gt | Lt | GtEq | LtEq | Eq | NotEq => 6,
 
             And => 3,
@@ -933,6 +936,7 @@ mod test {
         let range2 = Range::from_ints(Some(5), Some(6));
         let range3 = Range::from_ints(Some(5), None);
         let range4 = Range::from_ints(None, Some(8));
+        let range5 = Range::from_ints(Some(5), Some(5));
 
         assert!(range_of_ranges(vec![range1.clone()])?.end.is_some());
 
@@ -987,6 +991,12 @@ mod test {
         end: 8
         "###);
 
+        assert_yaml_snapshot!(range_of_ranges(vec![range5])?, @r###"
+        ---
+        start: 5
+        end: 5
+        "###);
+
         Ok(())
     }
 
