@@ -1,9 +1,9 @@
 # -*- coding: utf-8 -*-
 """Nox session configuration."""
 import os
-from typing import Any, List
+from typing import List
 from pathlib import Path
-
+import os
 import nox
 from nox.sessions import Session
 
@@ -21,6 +21,7 @@ nox.options.reuse_existing_virtualenvs = False
 @nox.session(python=VERSIONS)
 def tests(session: Session) -> None:
     """Run the test suite with pytest."""
-    session.install("-v", f"--find-links={Path('..', 'target' + os.sep + 'wheels')}", "prql_python")
+    print('CWD', os.getcwd())
+    session.install("-v", "--no-index", f"--find-links={Path('..', 'dist')}", "prql_python")
     session.install("-v", "-r", "requirements.txt")
     session.run("pytest", str(Path("python", "tests")))
